// gin响应模块
// 秒寻科技
// zt 2024-01-05

package resp

import (
	"net/http"

	"github.com/gin-gonic/gin"
)

// token过期
func RespTokenExpire(c *gin.Context, err string) {
	c.JSON(http.StatusOK, gin.H{
		"code": 2001,
		"msg":  err,
	})
}

// 响应失败
func RespFail(c *gin.Context, err string) {
	c.JSON(http.StatusOK, gin.H{
		"code": 2002,
		"msg":  err,
	})
}

// 响应成功，不返回数据
func RespOk(c *gin.Context) {
	c.JSON(http.StatusOK, gin.H{
		"code": 2000,
		"msg":  "success",
	})
}

// 响应成功，返回记录ID
func RespToken(c *gin.Context, token string) {
	c.JSON(http.StatusOK, gin.H{
		"code":  2000,
		"msg":   "success",
		"token": token,
	})
}

// 响应成功，返回记录ID
func RespId(c *gin.Context, id int) {
	c.JSON(http.StatusOK, gin.H{
		"code": 2000,
		"msg":  "success",
		"id":   id,
	})
}

// 响应成功，返回数据模型
func RespData(c *gin.Context, dataModel interface{}) {
	c.JSON(http.StatusOK, gin.H{
		"code": 2000,
		"msg":  "success",
		"data": dataModel,
	})
}

// 响应成功，返回数据列表
func RespList(c *gin.Context, dataList interface{}) {
	c.JSON(http.StatusOK, gin.H{
		"code": 2000,
		"msg":  "success",
		"data": dataList,
	})
}
